%define	major		3
%define libname		%mklibname svncpp %{major}
%define develname	%mklibname svncpp -d

Summary:	A cross-platform GUI for the Subversion concurrent versioning system
Name:		rapidsvn
Version:	0.12.1
Release:	%mkrel 10
License:	GPLv2+
Group:		Development/Tools
URL:		http://rapidsvn.tigris.org
Source0:	https://www.rapidsvn.org/download/release/%{version}/%{name}-%{version}.tar.gz
Source1:	https://raw.githubusercontent.com/RapidSVN/RapidSVN/master/doc/svncpp/svncpp.dox
Source2:	rapidsvn_logo.png
Patch1:		rapidsvn-0.12.0-linkage_fix.patch
Patch2:		rapidsvn-0.12.1-subversion1.9-private-api.patch
BuildRequires:	apache-devel >= 2.0.54
BuildRequires:	doxygen
BuildRequires:	subversion-devel >= 1.2
BuildRequires:	subversion >= 1.2
BuildRequires:	libtool >= 1.4.2
BuildRequires:	wxgtku2.8-devel
BuildRequires:	libxslt-proc
BuildRequires:	docbook-style-xsl
BuildRequires:	pkgconfig(neon) >= 0.27
BuildRequires:	imagemagick
BuildRequires:	pkgconfig(cppunit)
Requires:	subversion

%description
RapidSVN is a platform independent GUI client for the Subversion
revision system written in C++ using the wxWindows framework.

%package -n %{libname}
Summary:	RapidSVN shared SvnCpp C++ API libraries
Group:		System/Libraries

%description -n %{libname}
RapidSVN is a platform independent GUI client for the Subversion
revision system written in C++ using the wxWindows framework.

This package contains shared SvnCpp C++ API libraries for
RapidSVN.

%package -n %{develname}
Summary:	RapidSVN SvnCpp C++ API development libraries
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	libsvncpp-devel = %{version}-%{release}

%description -n %{develname}
As part of the RapidSVN effort it became clear that it would make
the code easier to update and manage if the Subversion client C
API were wrapped in C++. This is where SvnCpp comes from. Right
now it has the following aspects of the C API have been
abstracted: authentication, logging, status, notification, and
properties. SvnCpp should provide an object-oriented programming
interface to any project that uses C++ or a SWIG-compatible
language like Python or Java.

%prep
%setup -q
%patch -P 1 -p1
%patch -P 2 -p1

# hack to fix: error: "configuration file svncpp.dox not found!"
cp %{SOURCE1} doc/svncpp/

cp %{SOURCE2} rapidsvn_logo.png

# The upstream Makefile is currently set up for OS/X and tries to use an old
# version of Python-native msgfmt.py, which doesn't work with Python3. Instead,
# we switch back to using the gettext version of 'msgfmt'
sed -i s/\#MSGFMT=msgfmt/MSGFMT=msgfmt/ src/locale/Makefile.am
sed -i '/MSGFMT=python/d' src/locale/Makefile.am

%build
autoreconf -vfi

export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS -std=gnu++14"

%configure \
    --enable-shared \
    --disable-static \
    --with-svn-include=%{_includedir} \
    --with-svn-lib=%{_libdir} \
    --with-xsltproc=%{_bindir}/xsltproc \
    --with-apr-config=%{_bindir}/apr-1-config \
    --with-apu-config=%{_bindir}/apu-1-config

%make_build

%install
%make_install

find %{buildroot} -name "*.la" -delete

# Mandriva Icons
install -d %{buildroot}%{_iconsdir}/hicolor/{16x16,32x32,48x48}/apps

convert rapidsvn_logo.png -resize 16x16 %{buildroot}%{_iconsdir}/hicolor/16x16/apps/%{name}.png
convert rapidsvn_logo.png -resize 32x32 %{buildroot}%{_iconsdir}/hicolor/32x32/apps/%{name}.png
convert rapidsvn_logo.png -resize 48x48 %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=RapidSVN
Comment=A cross-platform GUI for the Subversion concurrent versioning system
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Development;RevisionControl;
EOF

#%%{__mv} doc/svncpp/html .

%find_lang %{name}

%files -f %{name}.lang
#%%doc html AUTHORS ChangeLog NEWS README
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/svncpp/
%{_libdir}/*.so


%changelog
* Sun Dec 22 2024 pterjan <pterjan> 0.12.1-10.mga10
+ Revision: 2128147
- Rebuild for patchN deprecation

* Tue Nov 01 2022 ghibo <ghibo> 0.12.1-9.mga9
+ Revision: 1900884
- Fix gcc12 building by forcing std=c++14
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Jan 08 2021 daviddavid <daviddavid> 0.12.1-8.mga8
+ Revision: 1669826
- fix build with python3
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Jul 24 2019 daviddavid <daviddavid> 0.12.1-6.mga8
+ Revision: 1423837
- add missing svncpp.dox file from upstream git to fix doc build
- fix Comment key entry from desktop file

* Sun Sep 23 2018 umeabot <umeabot> 0.12.1-5.mga7
+ Revision: 1300777
- Mageia 7 Mass Rebuild

* Wed Feb 17 2016 luigiwalser <luigiwalser> 0.12.1-4.mga6
+ Revision: 962965
- add patch from gentoo to fix build with subversion 1.9.x
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.12.1-3.mga5
+ Revision: 741720
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.12.1-2.mga5
+ Revision: 688610
- Mageia 5 Mass Rebuild

* Sun Mar 09 2014 wally <wally> 0.12.1-1.mga5
+ Revision: 601502
- clean .spec
- drop old and unneeded Mdv era provides/obsoletes
+ bersuit <bersuit>
- Update to new upstream version 0.12.1

* Sun Jan 13 2013 umeabot <umeabot> 0.12.0-8.mga3
+ Revision: 380182
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Oct 21 2012 malo <malo> 0.12.0-7.mga3
+ Revision: 309000
- update RPM group

* Thu Jan 19 2012 fwang <fwang> 0.12.0-6.mga2
+ Revision: 198407
- drop unused patch str fmt
- drop .la file

* Fri Dec 16 2011 wally <wally> 0.12.0-5.mga2
+ Revision: 182776
- wxGTK2.8-devel BR was renamed to wxgtk2.8-devel
+ ahmad <ahmad>
- Rebuild against wxgtk2.8 with enabled catch_segvs

* Mon Mar 07 2011 mikala <mikala> 0.12.0-3.mga1
+ Revision: 66097
- Drop BuildRoot
- Remove mdk macros
- imported package rapidsvn

